#
# spec file for package python-gwcs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-gwcs
Version:        0.24.0
Release:        1.3
Summary:        Generalized World Coordinate System
License:        BSD-3-Clause
Group:          Productivity/Scientific/Astronomy
URL:            https://gwcs.readthedocs.io/en/latest/
# SourceRepository: https://github.com/spacetelescope/gwcs
Source:         https://files.pythonhosted.org/packages/source/g/gwcs/gwcs-%{version}.tar.gz
BuildRequires:  %{python_module asdf >= 3.3.0}
BuildRequires:  %{python_module asdf-astropy >= 0.5.0}
BuildRequires:  %{python_module asdf_wcs_schemas >= 0.4.0}
BuildRequires:  %{python_module astropy >= 6}
BuildRequires:  %{python_module base >= 3.10}
BuildRequires:  %{python_module numpy >= 1.24}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module scipy >= 1.14.1}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-asdf >= 3.3.0
Requires:       python-asdf-astropy >= 0.5.0
Requires:       python-asdf_wcs_schemas >= 0.4.0
Requires:       python-astropy >= 6
Requires:       python-numpy >= 1.24
Requires:       python-scipy >= 1.14.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest-astropy >= 0.11.0}
BuildRequires:  %{python_module pytest >= 8}
# /SECTION
%python_subpackages

%description
An Astropy affiliated package providing tools for managing the
World Coordinate System of astronomical data.

%prep
%setup -q -n gwcs-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -ra

%files %{python_files}
%doc README.rst
%license licenses/LICENSE.rst licenses/README.rst
%{python_sitelib}/gwcs
%{python_sitelib}/gwcs-%{version}*-info

%changelog
* Wed Feb 12 2025 Ben Greiner <code@bnavigator.de>
- Update to 0.24.0
  * Coordinate frames now have a "native" order and then are sorted
    based on axes_order. [#457]
  * WCS.numerical_inverse no longer accepts high level objects
    (with_units= is not supported) use WCS.inverse. [#457]
  * CoordinateFrame.coordinates has been replaced by
    CoordinateFrame.to_high_level_coordinates [#457]
  * CoordinateFrame.to_quantity has been replaced by
    CoordinateFrame.from_high_level_coordinates. [#457]
  * Inputs to CelestialFrame, such as axes_names are now explicitly
    in lon, lat order and will re sorted based on axes_order=.
    [#457]
  * Implement code linting and automatic formatting. [#544]
  * Refactor WCS to use a Pipeline base class which adds basic
    checks to ensure that the pipeline is valid. These include
    checking for duplicate frame names and that the last transform
    is None. [#545]
  * Bugfix for WCS.invert and WCS.to_fits that prevented evaluation
    when the attached bounding box happened to have units on its
    values. [#554]
- No release 0.23.0 (skipped)
  * This was skipped to avoid issues with an ongoing JWST release.
- Release 0.22.0
  * Replace usages of copy_arrays with memmap [#503]
  * Fix an issue with units in wcs_from_points. [#507]
  * Fix incorrect units being returned in the low level WCS API.
    [#512]
  * Synchronize region.py with the copies of it in JWST and
    Romancal. [#517]
  * Add support for compound bounding boxes and ignored bounding
    box entries. [#519]
  * Add gwcs.examples module, based on the examples located in the
    testing conftest.py. [#521]
  * Force bounding_box to always be returned as a F ordered box.
    [#522]
  * Move the bounding box attachment to the forward transform
    property. [#532]
  * Adjust world_to_array_index_values to round to integer
    coordinates as specified by APE 14. [#525]
  * Add warning filter to asdf extension to prevent the
    bounding_box order warning for gwcs objects originating from a
    file. [#526]
  * Fixed a bug where evaluating the inverse transform did not
    respect the bounding box. [#498]
  * Improved reliability of inside/outside footprint computations
    when evaluating inverse transform with bounding box. [#536]
* Sun Apr  7 2024 Ben Greiner <code@bnavigator.de>
- Actually declare the minimum version requirement for
  asdf-wcs-schemas.
* Sun Apr  7 2024 Dirk Müller <dmueller@suse.com>
- update to 0.21.0:
  * Add a minimum version requirement for asdf-wcs-schemas.
  * Fix WCS.__str__ for instances without transforms.
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.20.0:
  * Replace ``pkg_resources`` with ``importlib.metadata``. [#478]
  * Serialize and deserialize ``pixel_shape`` with asdf. [#480]
  * Synchronize ``array_shape`` and ``pixel_shape`` attributes of
    WCS objects. [#439]
  * Fix failures and warnings with numpy 2.0. [#472]
  * Remove deprecated old ``bounding_box``. The new
    implementation is released with
  * Refactor ``CoordinateFrame.axis_physical_types``. [#459]
  * ``StokesFrame`` uses now ``astropy.coordinates.StokesCoord``.
  * Dropped support for Python 3.8. [#451]
  * Fixed a call to ``astropy.coordinates`` in
    ``wcstools.wcs_from_points``. [#448]
  * Code and docstrings clean up. [#460]
  * Register all available asdf extension manifests from ``asdf-
    wcs-schemas``
* Fri Jan 13 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.18.3
  * Fix pixel scale formula used by iterative inverse by @mcara in
    [#423]
  * refactor for Tox 4 by @zacharyburnett in #428
  * Improve stability of SIP fitting. Fix constant term - CRPIX -
    in SIP by @mcara in #427
  * use canonical name of RTD config and enable nitpicky mode to
    catch broken links in docs by @zacharyburnett in #430
  * add downstream tests for JWST and Roman calibration pipelines
    by @zacharyburnett in #415
  * fix CRDS_PATH in CI when running downstream tests by
    @zacharyburnett in #432
* Thu Oct 27 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.18.2
  * Corrected the reported requested forward SIP accuracy and
    reported fit residuals by to_fits_sip() and to_fits(). [#413,
    [#419]]
  * Fixed a bug due to which the check for divergence in
    _fit_2D_poly() and hence in to_fits() and to_fits_sip() was
    ignored. [#414]
* Thu Mar 17 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.18.1
  * Bug fix update
  * Remove references to the ``six`` package. [#402]
  * Fix asdf-astropy related test failure
* Tue Dec 28 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.18.0
  * Bug Fixes
  * Updated code in region.py with latest improvements and bug
    fixes from stsci.skypac.regions.py [#382]
  * New Features
  * Enabled CompoundBoundingBox support for wcs. [#375]
  * Moved schemas to standalone package asdf-wcs-schemas. Reworked
    the serialization code to use ASDF converters. [#388]
- Release 0.17.1
  * Bug Fixes
  * Fixed a bug with StokesProfile and array types. [#384]
- Release 0.17.0
  * Bug Fixes
  * world_axis_object_components and world_axis_object_classes now
    ensure unique keys in CompositeFrame and CoordinateFrame.
    [#356]
  * Fix issue where RuntimeWarning is raised when there are NaNs in
    coordinates in angle wrapping code [#367]
  * Fix deprecation warning when wcs is initialized with a pipeline
    [#368]
  * Use CD formalism in WCS.to_fits_sip(). [#380]
  * New Features
  * wcs_from_points now includes fitting for the inverse transform.
    [#349]
  * Generalized WCS.to_fits_sip to be able to create a 2D celestial
    FITS WCS from celestial subspace of the WCS. Also, now
    WCS.to_fits_sip` supports arbitrary order of output axes.
    [#357]
  * API Changes
  * Modified interface to wcs_from_points function to better match
    analogous function in astropy. [#349]
  * Model._BoundingBox was renamed to Model.ModelBoundingBox.
    [#376, #377]
* Thu Feb 11 2021 Ben Greiner <code@bnavigator.de>
- Actually do the update to 0.16.1 m-)
- Skip schema tests not tolerating any deprecation warnings from
  numpy 1.20 -- Already fixed upstream, but patch is too
  unspecific gh#spacetelescope/gwcs#353
* Mon Jan 18 2021 Benjamin Greiner <code@bnavigator.de>
- Update to 0.16.1
  * Fix a regression with pixel_to_world for output frames with one
    axis. [#342]
- Skip python36 because python36-astropy is not available.
* Sat Dec 19 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 0.16.0
  * Added an option to to_fits_sip() to be able to specify the
    reference point (crpix) of the FITS WCS. [#337]
  * Added support for providing custom range of degrees in
    to_fits_sip. [#339]
  * Bounding_box now works with tuple of Quantities. [#331]
  * Fix a formula for estimating crpix in to_fits_sip() so that
    crpix is near the center of the bounding box. [#337]
  * Allow sub-pixel sampling of the WCS model when computing SIP
    approximation in to_fits_sip(). [#338]
  * Fixed a bug in to_fits_sip due to which inv_degree was
    ignored. [#339]
- 0.15.0 changelog
  * Added insert_frame method to modify the pipeline of a
    WCS object. [#299]
  * Added to_fits_tab method to generate FITS header and binary
    table extension following FITS WCS -TAB convention. [#295]
  * Added in_image function for testing whether a point in world
    coordinates maps back to the domain of definition of the
    forward transformation. [#322]
  * Implemented iterative inverse for imaging WCS. [#324]
- 0.14.0 changelog
  * Updated versions of schemas for gwcs objects based on
    latest versions of transform schemas in asdf-standard.
    [#307]
  * Added a wcs.Step class to allow serialization to ASDF to
    use references. [#317]
  * WCS.pipeline now is a list of Step instances instead of
    a (frame, transform) tuple. Use WCS.pipeline.transform and
    WCS.pipeline.frame to access them. [#319]
  * Fix a bug in polygon fill for zero-width bounding boxes.
    [#293]
  * Add an optional parameter input_frame to
    ``wcstools.wcs_from_fiducial`. [#312]
* Mon Jun  8 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.13.0
  - Added two new transforms - ``SphericalToCartesian`` and
  ``CartesianToSpherical``. [#275, #284, #285]
  - Added ``to_fits_sip`` method to generate FITS header with SIP keywords [#286]
  - Added ``get_ctype_from_ucd`` function. [#288]
  - Fixed an off by one issue in ``utils.make_fitswcs_transform``. [#290]
* Mon Jan  6 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.12.0
  + New Features
  * ``gwcs.WCS`` now supports the ``world_axis_object_components`` and
    ``world_axis_object_classes`` methods of the low level WCS API as specified by
    APE 14.
  * Removed astropy-helpers from package.
  * Added a method ``fix_inputs`` which rturns an unique WCS from a compound
    WCS by fixing inputs.
  * Added two new transforms - ``ToDirectionCosines`` and ``FromDirectionCosines``.
  * Added new transforms ``WavelengthFromGratingEquation``, ``AnglesFromGratingEquation3D``.
  * ``gwcs.WCS`` now supports the new ``world_axis_names`` and
    ``pixel_axis_names`` properties on ``LowLevelWCS`` objects.
  * Update the ``StokesFrame`` to work for arrays of coordinates and integrate
    with APE 14.
  * Added ``Snell3D``, ``SellmeierGlass`` and ``SellmeierZemax`` transforms.
  + API Changes
  * Changed the initialization of ``TemporalFrame`` to be consistent with other
    coordinate frames.
  + Bug Fixes
  * Ensure that ``world_to_pixel_values`` and ``pixel_to_world_values`` always
    accept and return floats, even if the underlying transform uses units.
- Drop python2 subpackage due to dependencies dropping python2.
* Sat Sep 14 2019 Benjamin Greiner <code@bnavigator.de>
- initial spec
